summaryrefslogtreecommitdiffstats
path: root/demux/stheader.h
diff options
context:
space:
mode:
Diffstat (limited to 'demux/stheader.h')
-rw-r--r--demux/stheader.h21
1 files changed, 19 insertions, 2 deletions
diff --git a/demux/stheader.h b/demux/stheader.h
index 6be3b16463..036c8f54e7 100644
--- a/demux/stheader.h
+++ b/demux/stheader.h
@@ -48,8 +48,10 @@ struct sh_stream {
bool dependent_track; // container dependent track flag
bool visual_impaired_track; // container flag
bool hearing_impaired_track;// container flag
- bool still_image; // video stream contains still images
+ bool image; // video stream is an image
+ bool still_image; // video consists of multiple sparse still images
int hls_bitrate;
+ int program_id;
struct mp_tags *tags;
@@ -70,6 +72,18 @@ struct mp_codec_params {
// E.g. "h264" (usually corresponds to AVCodecDescriptor.name)
const char *codec;
+ // Usually corresponds to AVCodecDescriptor.long_name
+ const char *codec_desc;
+
+ // Corresponding codec profile
+ const char *codec_profile;
+
+ // E.g. "h264" (usually corresponds to AVCodec.name)
+ const char *decoder;
+
+ // Usually corresponds to AVCodec.long_name
+ const char *decoder_desc;
+
// Usually a FourCC, exact meaning depends on codec.
unsigned int codec_tag;
@@ -103,10 +117,13 @@ struct mp_codec_params {
int disp_w, disp_h; // display size
int rotate; // intended display rotation, in degrees, [0, 359]
int stereo_mode; // mp_stereo3d_mode (0 if none/unknown)
- struct mp_colorspace color; // colorspace info where available
+ struct pl_color_space color; // colorspace info where available
+ struct pl_color_repr repr; // color representaion info where available
+ struct mp_rect crop; // crop to be applied
// STREAM_VIDEO + STREAM_AUDIO
int bits_per_coded_sample;
+ char *format_name; // pixel format (video) or sample format (audio)
// STREAM_SUB
double frame_based; // timestamps are frame-based (and this is the